#
# spec file for package python-qtdatavis3d-qt5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plainpython python
%define mname qtdatavis3d-qt5

%{?sle15_python_module_pythons}
Name:           python-%{mname}
Version:        5.15.5
Release:        2.4
Summary:        Python bindings for the Qt5 Data Visualization library
License:        GPL-3.0-only
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/pyqtdatavisualization/intro
Source:         https://files.pythonhosted.org/packages/source/P/PyQtDataVisualization/PyQtDataVisualization-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyqt-builder >= 1.9}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module sip-devel >= 5.3}
BuildRequires:  fdupes
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5DataVisualization)
Requires:       python-qt5 >= %{version}
Requires:       python-qt5-sip
Provides:       python-PyQtDataVisualization = %{version}-%{release}
%python_subpackages

%description
PyQtDataVisualization is a set of Python bindings for the Qt5 Data
Visualization library.


%package devel
Summary:        Sip and eric API files for %{name}
Group:          Development/Libraries/Python
Provides:       python-%{mname}-sip = %{version}-%{release}
Obsoletes:      python-%{mname}-sip < %{version}-%{release}
Provides:       python-%{mname}-api = %{version}-%{release}
Obsoletes:      python-%{mname}-api < %{version}-%{release}
Provides:       %{plainpython}-%{mname}-sip = %{version}-%{release}
Obsoletes:      %{plainpython}-%{mname}-sip < %{version}-%{release}
Provides:       %{plainpython}-%{mname}-api = %{version}-%{release}
Obsoletes:      %{plainpython}-%{mname}-api < %{version}-%{release}
Requires:       python-qt5-devel
Requires:       %{plainpython}(abi) = %{python_version}
Supplements:    (eric and python-%{mname})
Supplements:    (python-qt5-devel and python-%{mname})

%description devel
This package provides the SIP files used to generate the Python bindings 
and Qt5 Data Visualization library API files for the Eric IDE for %{name}.

%package doc
Summary:        Examples for %{name}
Group:          Documentation/Other
Provides:       %{python_module %{mname}-examples = %{version}-%{release}}
BuildArch:      noarch

%description doc
This package provides %{name} examples.

%prep
%setup -q -n PyQtDataVisualization-%{version}

%build
%pyqt_build

%install
%pyqt_install
%pyqt_install_examples %mname

%files %{python_files}
%license LICENSE
%doc NEWS README
%dir %{python_sitearch}/PyQt5/
%{python_sitearch}/PyQt5/QtDataVisualization.*
%{python_sitearch}/PyQtDataVisualization-%{version}.dist-info/

%files %{python_files devel}
%license LICENSE
%{pyqt5_sipdir}/QtDataVisualization/
%dir %{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/PyQtDataVisualization.api

%files %{python_files doc}
%license LICENSE
%{_docdir}/%{python_prefix}-%{mname}
%exclude %{_docdir}/%{python_prefix}-%{mname}/NEWS
%exclude %{_docdir}/%{python_prefix}-%{mname}/README

%changelog
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module for more modern python in 15.x
* Wed Jan 11 2023 Ben Greiner <code@bnavigator.de>
- Merge -sip and -api package into -devel
* Wed Jan 11 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.15.5
  * Added support for Python v3.10.
* Mon Sep 13 2021 Ben Greiner <code@bnavigator.de>
- Remove the Supplements for python-sip -- boo#1190441
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Provide the PyPI name
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.15.4
  * Packaging bug fixes.
- Fixes problems with packages checking the package metadata like
  boo#1183144
* Fri Feb 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.15.3
  * Sync release with PyQt5
- Switch all distros to SIP v5+
- Disable Python 2 build
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.2
  * Build system changes
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- use sip5 where available
* Mon Sep 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 5.15.1
  * A bug-fix release.
- remove the superfluous Tumbleweed python2 skip hack
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.15.0
  * Added support for Qt v5.15.0.
- v5.14.0 added support for Qt v5.14.0 in December 2019
- The source location has changed to PyPI
* Fri Mar 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building the python2 package for openSUSE Tumbleweed.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.13.1
  * Added support for SIP v5.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  * Bindings updated for QtDataVis 5.13.0.
* Wed Feb 27 2019 Todd R <toddrme2178@gmail.com>
- Make eric api files supplement eric.
- Make sip api files supplement sip.
- Fix sip api dependency.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Consistency fixes with the other python-qt5 add-on packages.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.12
  * Updated for Qt v5.12.1.
- Build both python2 and python3 flavors in a single spec file.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
- Update to 5.11.3. Changes since 5.10.1:
  * Fixed all signal signatures.
  * Add support for recent Qt versions.
* Tue Apr 17 2018 termim@gmail.com
- Update to 5.10.1
  * Added support for Qt Charts v5.10.1.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to 5.10
  * Added support for Qt Data Visualization v5.10.0.
  version 5.9.2
  * Added support for Qt Data Visualization v5.9.3.
  version 5.9.1
  * Added support for Qt Data Visualization v5.9.2.
  version 5.9
  * Added support for Qt Data Visualization v5.9.0 and v5.9.1.
* Wed Feb 15 2017 termim@gmail.com
- Update to 5.8
* Tue Jan  3 2017 termim@gmail.com
- Update to 5.7.1
* Fri Jul 29 2016 termim@gmail.com
- Initial checkin v.2.0.1
